==> mt_metadata-0.1.7.tar.gz: mt_metadata-0.1.7/mt_metadata/transfer_functions/io/edi/metadata/emeasurement.py <==
# -*- coding: utf-8 -*-
"""
Created on Sat Dec  4 16:21:06 2021

@author: jpeacock
"""

# =============================================================================
# Imports
# =============================================================================
import numpy as np

from mt_metadata.base.helpers import write_lines
from mt_metadata.base import get_schema, Base
from .standards import SCHEMA_FN_PATHS

# =============================================================================
attr_dict = get_schema("emeasurement", SCHEMA_FN_PATHS)

# ==============================================================================
# magnetic measurements
# ==============================================================================
class EMeasurement(Base):
    __doc__ = write_lines(attr_dict)

    def __init__(self, **kwargs):

        self._fmt_dict = {
            "id": "<",
            "chtype": "<",
            "x": "<.2f",
            "y": "<.2f",
            "z": "<.2f",
            "x2": "<.2f",
            "y2": "<.2f",
            "z2": "<.2f",
            "acqchan": "<",
        }

        super().__init__(attr_dict=attr_dict, **kwargs)

    def __str__(self):
        return "\n".join([f"{k} = {v}" for k, v in self.to_dict(single=True).items()])

    def __repr__(self):
        return self.__str__()

    @property
    def dipole_length(self):
        if hasattr(self, "z"):
            return np.sqrt(
                (self.x2 - self.x) ** 2 + (self.y2 - self.y) ** 2 + self.z ** 2
            )
        else:
            return np.sqrt((self.x2 - self.x) ** 2 + (self.y2 - self.y) ** 2)

    @property
    def azimuth(self):
        if hasattr(self, "azm"):
            return self.azm
        try:
            return np.rad2deg(np.arctan2((self.y2 - self.y), (self.x2 - self.x)))
        except ZeroDivisionError:
            return 0.0

    @property
    def channel_number(self):
        if self.acqchan != None:
            if not isinstance(self.acqchan, (int, float)):
                try:
                    return [int("".join(i for i in self.acqchan if i.isdigit()))][0]
                except (IndexError, ValueError):
                    return 0
            return self.acqchan
        return 0

==> mt_metadata-0.2.1.tar.gz: mt_metadata-0.2.1/mt_metadata/transfer_functions/io/edi/metadata/emeasurement.py <==
# -*- coding: utf-8 -*-
"""
Created on Sat Dec  4 16:21:06 2021

@author: jpeacock
"""

# =============================================================================
# Imports
# =============================================================================
import numpy as np

from mt_metadata.base.helpers import write_lines
from mt_metadata.base import get_schema, Base
from .standards import SCHEMA_FN_PATHS

# =============================================================================
attr_dict = get_schema("emeasurement", SCHEMA_FN_PATHS)

# ==============================================================================
# magnetic measurements
# ==============================================================================
class EMeasurement(Base):
    __doc__ = write_lines(attr_dict)

    def __init__(self, **kwargs):

        self._fmt_dict = {
            "id": "<",
            "chtype": "<",
            "x": "<.2f",
            "y": "<.2f",
            "z": "<.2f",
            "x2": "<.2f",
            "y2": "<.2f",
            "z2": "<.2f",
            "azm": "<.2f",
            "acqchan": "<",
        }

        super().__init__(attr_dict=attr_dict, **kwargs)

        if self.azm == 0:
            self.azm = self.azimuth

    def __str__(self):
        return "\n".join(
            [f"{k} = {v}" for k, v in self.to_dict(single=True).items()]
        )

    def __repr__(self):
        return self.__str__()

    @property
    def dipole_length(self):
        try:
            if hasattr(self, "z"):
                return np.sqrt(
                    (self.x2 - self.x) ** 2
                    + (self.y2 - self.y) ** 2
                    + self.z**2
                )
            else:
                return np.sqrt(
                    (self.x2 - self.x) ** 2 + (self.y2 - self.y) ** 2
                )
        except TypeError:
            return 0

    @property
    def azimuth(self):
        if hasattr(self, "azm"):
            if self.azm != 0:
                return self.azm
        try:
            return np.rad2deg(
                np.arctan2((self.y2 - self.y), (self.x2 - self.x))
            )
        except (ZeroDivisionError, TypeError):
            return 0.0

    @property
    def channel_number(self):
        if self.acqchan != None:
            if not isinstance(self.acqchan, (int, float)):
                try:
                    return [
                        int("".join(i for i in self.acqchan if i.isdigit()))
                    ][0]
                except (IndexError, ValueError):
                    return 0
            return self.acqchan
        return 0
